{% load gaston_tags %}

<ul class="depth-{{ depth_count }}">
{% for item in menu %}
    <li class="{% get_item_css_classes item %}">
        <a href="{{ item.url }}">
            {{ item.label }}
        </a>
        {% if item.submenu %}
			{% menu item.submenu depth_count %}
        {% endif %}
    </li>
{% endfor %}
</ul>
